# OpenDR 3D Object Detection - Voxel-Based 3D Object Detection using TANet and PointPillars

This folder contains the OpenDR Learner class implemented for the 3D Object Detection task. 

## Sources

Large parts of the Learner code are taken from [happinesslz/TANet](
https://github.com/happinesslz/TANet) (which is based on PointPillars and SECOND code, the folder is second_detector) with modifications to make them compatible 
with OpenDR specifications.
